package com.ylx.web.controller.massage;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ylx.common.constant.MassageConstants;
import com.ylx.massage.domain.TJs;
import com.ylx.massage.domain.vo.TJsVo;
import com.ylx.massage.enums.JsStatusEnum;
import com.ylx.massage.service.TJsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;


import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;

/**
 * 技师Controller
 *
 * @author ylx
 * @date 2024-03-22
 */
@RestController
@RequestMapping("api/js/v1")
@Api(tags = {"技师管理"})
public class TJsController {
    @Resource
    private TJsService jsService;

    /**
     * 添加技师申请
     *
     * @param js
     * @return
     */
    @RequestMapping(value = "wx/add", method = RequestMethod.POST)
    @ApiOperation("添加技师申请")
    public Boolean add(@RequestBody TJs js) {
        // 评分默认最高
        js.setnStar(MassageConstants.INTEGER_FIVE);
        // 已服务数量 0
        js.setnNum(MassageConstants.INTEGER_ZERO);
        // 佣金比例 10
        js.setnBili(MassageConstants.INTEGER_TEN);
        // 服务状态
        js.setnStatus(JsStatusEnum.JS_SERVICEABLE.getCode());
        // 上岗状态
        js.setnStatus2(JsStatusEnum.POST_NOT_ON_DUTY.getCode());
        // 审核状态
        js.setnTong(JsStatusEnum.JS_NOT_PASS.getCode());
        js.setnB1(MassageConstants.INTEGER_ZERO);
        js.setnB2(MassageConstants.INTEGER_ZERO);
        js.setnB3(MassageConstants.INTEGER_ZERO);
        js.setDtCreateTime(LocalDateTime.now());
        return jsService.save(js);
    }

    /**
     * 更新技师信息
     *
     * @param js
     * @return
     */
    @RequestMapping(value = "wx/update", method = RequestMethod.POST)
    @ApiOperation("更新技师信息")
    public Boolean wxUpdate(@RequestBody TJs js) {
        return jsService.updateById(js);
    }

    /**
     * 微信查询
     *
     * @param param
     * @return
     */
    @RequestMapping(value = "wx/select", method = RequestMethod.POST)
    @ApiOperation("微信查询")
    public List<TJs> wxSelect(@RequestBody TJsVo param) {
        return jsService.getAll(param);
    }


    /**
     * 分页查询数据
     */
    @RequestMapping(value = "/select", method = RequestMethod.GET)
    @ApiOperation("分页查询数据")
    public Page<TJs> selectSp(Page<TJs> page, TJs js) {
        LambdaQueryWrapper<TJs> mhCompanyLambdaQueryWrapper = new LambdaQueryWrapper<>();
        mhCompanyLambdaQueryWrapper.eq(null != js.getnTong(), TJs::getnTong, js.getnTong()).
                like(StringUtils.isNotBlank(js.getcName()), TJs::getcName, js.getcName()).
                orderByDesc(TJs::getDtCreateTime);
        return jsService.page(page, mhCompanyLambdaQueryWrapper);
    }


    /**
     * 删除
     */
    @RequestMapping(value = "/del", method = RequestMethod.POST)
    @ApiOperation("删除")
    public Boolean del(@RequestBody TJs js) {
        return jsService.removeById(js);
    }
}
