package com.ylx.web.controller.massage;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ylx.common.constant.MassageConstants;
import com.ylx.common.core.domain.R;
import com.ylx.common.utils.uuid.IdUtils;
import com.ylx.massage.domain.TXiangmu;
import com.ylx.massage.service.TXiangmuService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;

/**
 * Controller
 *
 * @author ylx
 * @date 2024-03-22
 */
@RestController
@RequestMapping("api/xiangmu/v1")
@Slf4j
@Api(tags = {"项目管理"})
public class TXiangmuController {
    @Resource
    private TXiangmuService xiangmuService;

    /**
     * 获取所有项目
     *
     * @return
     */
    @RequestMapping(value = "wx/getAll", method = RequestMethod.POST)
    @ApiOperation("获取所有项目")
    public R<List<TXiangmu>> geTXiangmu(TXiangmu tXiangmu) {
        LambdaQueryWrapper<TXiangmu> objectLambdaQueryWrapper = new LambdaQueryWrapper<>();
        objectLambdaQueryWrapper.eq(StringUtils.isNotBlank(tXiangmu.getcId()), TXiangmu::getcId, tXiangmu.getcId()).
                orderByDesc(TXiangmu::getDtCreateTime);
        List<TXiangmu> list = xiangmuService.list(objectLambdaQueryWrapper);
        return R.ok(list);
    }

    /**
     * 添加或者更新项目
     *
     * @param xiangmu
     * @return
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ApiOperation("添加或者更新项目")
    public R saveOrUpdate(@RequestBody TXiangmu xiangmu) {
        try {
            if (StringUtils.isBlank(xiangmu.getcId())) {
                xiangmu.setcId(IdUtils.fastSimpleUUID());
                xiangmu.setnSaleNumber(MassageConstants.INTEGER_ZERO);
                xiangmu.setDtCreateTime(LocalDateTime.now());
            }
            return R.ok(xiangmuService.saveOrUpdate(xiangmu));
        } catch (Exception e) {
            log.error("saveOrUpdate", e);
            return R.fail();
        }
    }


    /**
     * 分页查询数据
     */
    @RequestMapping(value = "/select", method = RequestMethod.GET)
    @ApiOperation("分页查询数据")
    public R<Page<TXiangmu>> selecTXiangmu(Page<TXiangmu> page, TXiangmu tXiangmu) {
        LambdaQueryWrapper<TXiangmu> objectLambdaQueryWrapper = new LambdaQueryWrapper<>();
        objectLambdaQueryWrapper.like(StringUtils.isNotBlank(tXiangmu.getcTitle()), TXiangmu::getcTitle, tXiangmu.getcTitle()).
                orderByDesc(TXiangmu::getDtCreateTime);
        // 获取查询返回结果
        Page<TXiangmu> pageSelect = xiangmuService.page(page, objectLambdaQueryWrapper);
        return R.ok(pageSelect);
    }

    /**
     * 删除项目
     *
     * @param xiangmu
     * @return
     */
    @RequestMapping(value = "/del", method = RequestMethod.POST)
    @ApiOperation("删除项目")
    public R del(@RequestBody TXiangmu xiangmu) {
        return R.ok(xiangmuService.removeById(xiangmu));
    }
}
